import { useRef } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';

import useTooltipPosition from './_hooks/useTooltipPosition';

import classes from './styles.module.scss';

/**
 * Render a hovering tooltip card that moves with the mouse.
 */
const HoverDisplay = function HoverDisplay(props) {
  const {
    tooltip,
    children,
    zIndex,
    className,
  } = props;

  const { active } = tooltip.config;

  const self = useRef();

  const [x, y] = useTooltipPosition({
    childNode: self,
    active,
  });

  return (
    <div
      ref={self}
      className={classnames(
        classes['tooltip-hover-display'],
        { [classes.active]: active },
        className,
      )}
      style={{
        top: y,
        left: x,
        zIndex,
      }}
    >
      {children}
    </div>
  );
};

HoverDisplay.defaultProps = {
  children: null,
  zIndex: undefined,
  className: undefined,
};

HoverDisplay.propTypes = {
  /**
   * A tooltip object as provided by `useTooltip`
   */
  tooltip: PropTypes.shape({
    config: PropTypes.shape({
      active: PropTypes.bool,
    }),
  }).isRequired,
  /**
   * The children to render inside the tooltip
   */
  children: PropTypes.node,
  /**
   * An override for the tooltip's z-index
   */
  zIndex: PropTypes.oneOfType([
    PropTypes.number,
    PropTypes.string,
  ]),
  /**
   * Custom class names to customize the tooltip. Must be recognizable by the
   * classnames library.
   */
  className: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.array,
    PropTypes.object,
  ]),
};

export default HoverDisplay;
