import Template from './_advancedTemplate';
import ContentComponent from './_common/ContentComponent';

const AdvancedTooltipMixedContent = Template.bind({});

AdvancedTooltipMixedContent.args = {
  useTooltipOptions: {
    content: ContentComponent,
  },
  triggerProps: [
    { props: { text: 'Hello from Tooltip 1!' } },
    { content: <div style={{ color: 'darkblue' }}>Plain content 2</div> },
    { props: { text: 'Hello from Tooltip 3!' } },
  ],
};

AdvancedTooltipMixedContent.parameters = {
  docs: {
    description: {
      story: `
Here again we are using the \`useTooltip\` hook to coordinate our own
\`TooltipDisplay\` and \`TooltipTrigger\` components, but now we're using
a mixed approach to specify our content. We set up the same default component
type to use by passing it to the \`useTooltip\` hook, but we pass plain content
as the \`content\` prop for our second \`TooltipTrigger\`. Tooltips one and
three use the default component type, so they get the colored background, but
tooltip two overrides the default and renders its plain content as-is.

You could also have a \`TooltipTrigger\` specify its own component type as its
\`content\` prop if you wanted to.
`,
    },
    source: {
      code: `
import { useTooltip, TooltipDisplay, TooltipTrigger } from '@politico/interactive-style';
import MyTooltipContentComponent from './MyTooltipContentComponent';

const MyParentComponent = function MyParentComponent(props) {
  const tooltip = useTooltip({
    content: MyTooltipContentComponent,
  });

  return (
    <div>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 1!' }}
      >
        <Target>Tooltip trigger content 1</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        content={<div style={{ color: 'darkblue' }}>Plain content 2</div>}
      >
        <Target>Tooltip trigger content 2</Target>
      </TooltipTrigger>
      <TooltipTrigger
        tooltip={tooltip}
        props={{ text: 'Hello from Tooltip 3!' }}
      >
        <Target>Tooltip trigger content 3</Target>
      </TooltipTrigger>
      <TooltipDisplay tooltip={tooltip} />
    </div>
  );
};

export default MyParentComponent;
`,
    },
  },
};

export default AdvancedTooltipMixedContent;
